Generic template and forward in stringstream.
This CL updates the templates in the StringStream to match more types.
All of the internal `operator<<` methods have been converted over to
StringStream. The precision was increased in order to better match the
precision needed to read back as a double.
Bug: tint:1686
Change-Id: Iaa15cf247f174967dd1014647ba5a74804997c22
Reviewed-on: https://dawn-review.googlesource.com/c/dawn/+/122080
Kokoro: Kokoro <noreply+kokoro@google.com>
Reviewed-by: Ben Clayton <bclayton@google.com>
Commit-Queue: Dan Sinclair <dsinclair@chromium.org>
diff --git a/src/tint/ast/unary_op.h b/src/tint/ast/unary_op.h
index a861af3..368803d 100644
--- a/src/tint/ast/unary_op.h
+++ b/src/tint/ast/unary_op.h
@@ -15,7 +15,7 @@
#ifndef SRC_TINT_AST_UNARY_OP_H_
#define SRC_TINT_AST_UNARY_OP_H_
-#include <ostream>
+#include "src/tint/utils/string_stream.h"
namespace tint::ast {
@@ -28,10 +28,10 @@
kNot, // !EXPR
};
/// @param out the std::ostream to write to
/// @param mod the UnaryOp
-/// @return the std::ostream so calls can be chained
-std::ostream& operator<<(std::ostream& out, UnaryOp mod);
+/// @return the stream so calls can be chained
+utils::StringStream& operator<<(utils::StringStream& out, UnaryOp mod);
} // namespace tint::ast
@@ -28,10 +28,10 @@
kNot, // !EXPR
};
-/// @param out the std::ostream to write to
+/// @param out the stream to write to
/// @param mod the UnaryOp